@@ -9,6 +9,6 @@ checktime = 600
 # "Paranoia" level. Specify in what case you should get notification. There are 3 avaiable modes: low, medium and high. Default is medium
 paranoia = 'medium'
 
-# Log file
-log = '/var/log/ip-checker'
+# Location of log file
+log = '/tmp/ipchecker.log'
 
